@@ -60,7 +60,7 @@ option 'files',
 
 option 'rollback',
     is => 'ro',
-    default => 0,
+    default => 1,
     negativable => 1;
 
 
@@ -106,14 +106,18 @@ has '_manifest',
 
 sub execute {
     my $self = shift;
+    unless (scalar @{$self->files}) {
+        INFO "Nothing to deploy; exiting";
+        return;
+    }
     $self->_manifest->writeToFile('src/package.xml');
-    $self->_session->Metadata->deployMetadata(
+    print $self->_session->Metadata->deployMetadata(
         $self->_zipFile,
         {
             singlePackage => 'true',
-            ($self->rollback ? (rollbackonerror => 'true') : ()),
+            ($self->rollback ? (rollbackOnError => 'true') : ()),
             ($self->validate ? (checkOnly => 'true') : ()),
-            ($self->runtests ? (testLevel => 'runLocalTests') : ()),
+            ($self->runtests ? (testLevel => 'RunLocalTests') : ()),
         }
     );
 }
@@ -130,7 +134,7 @@ App::SFDC::Deploy - Deploy files to SFDC
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 OPTIONS
 
